@@ -1,5 +1,5 @@
 /*
- * Copyright 2017 Red Hat, Inc. and/or its affiliates.
+ * Copyright 2019 Red Hat, Inc. and/or its affiliates.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -36,6 +36,7 @@ import org.jbpm.workbench.common.client.filters.active.ActiveFilterItem;
 import org.jbpm.workbench.common.client.filters.basic.BasicFilterAddEvent;
 import org.jbpm.workbench.common.client.filters.basic.BasicFilterRemoveEvent;
 import org.jbpm.workbench.common.client.list.ListTable;
+import org.jbpm.workbench.common.client.menu.ServerTemplateSelectorMenuBuilder;
 import org.jbpm.workbench.df.client.filter.FilterSettings;
 import org.jbpm.workbench.df.client.list.DataSetQueryHelper;
 import org.jbpm.workbench.ht.client.resources.i18n.Constants;
@@ -43,6 +44,7 @@ import org.jbpm.workbench.ht.model.TaskSummary;
 import org.jbpm.workbench.ht.model.events.TaskCompletedEvent;
 import org.jbpm.workbench.ht.model.events.TaskSelectionEvent;
 import org.jbpm.workbench.ht.service.TaskService;
+import org.jbpm.workbench.ht.util.TaskStatus;
 import org.junit.Before;
 import org.junit.Test;
 import org.kie.server.controller.api.model.spec.Capability;
@@ -59,6 +61,7 @@ import org.uberfire.client.workbench.events.BeforeClosePlaceEvent;
 import org.uberfire.ext.widgets.common.client.breadcrumbs.UberfireBreadcrumbs;
 import org.uberfire.mocks.CallerMock;
 import org.uberfire.mocks.EventSourceMock;
+import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.mvp.impl.DefaultPlaceRequest;
 
 import static java.util.Collections.emptyList;
@@ -67,6 +70,8 @@ import static java.util.Collections.singletonList;
 import static org.dashbuilder.dataset.filter.FilterFactory.equalsTo;
 import static org.dashbuilder.dataset.filter.FilterFactory.in;
 import static org.dashbuilder.dataset.filter.FilterFactory.likeTo;
+import static org.jbpm.workbench.common.client.PerspectiveIds.SEARCH_PARAMETER_PROCESS_INSTANCE_ID;
+import static org.jbpm.workbench.common.client.PerspectiveIds.SEARCH_PARAMETER_TASK_ID;
 import static org.jbpm.workbench.ht.client.util.TaskUtils.TaskType;
 import static org.jbpm.workbench.ht.client.util.TaskUtils.getStatusByType;
 import static org.jbpm.workbench.ht.model.TaskDataSetConstants.*;
@@ -78,8 +83,9 @@ import static org.mockito.Mockito.*;
 
 public abstract class AbstractTaskListPresenterTest {
 
-    private static final Long TASK_ID = 1L;
-    private static final String TASK_DEPLOYMENT_ID = "deploymentId";
+    protected static final Long TASK_ID = 1L;
+    protected static final String TASK_DEPLOYMENT_ID = "deploymentId";
+    protected static final String USER_ID = "userId";
 
     @Mock
     protected User identity;
@@ -122,6 +128,9 @@ public abstract class AbstractTaskListPresenterTest {
     @Mock
     protected PerspectiveActivity perspectiveActivity;
 
+    @Mock
+    private ServerTemplateSelectorMenuBuilder serverTemplateSelectorMenuBuilder;
+
     @Spy
     protected FilterSettings filterSettings;
 
@@ -160,13 +169,13 @@ public abstract class AbstractTaskListPresenterTest {
         dataSetLookup.setDataSetUUID(HUMAN_TASKS_DATASET);
 
         when(filterSettings.getDataSetLookup()).thenReturn(dataSetLookup);
-
         when(viewMock.getListGrid()).thenReturn(extendedPagedTable);
         when(extendedPagedTable.getPageSize()).thenReturn(10);
         when(dataSetQueryHelper.getCurrentTableSettings()).thenReturn(filterSettings);
         when(filterSettings.getKey()).thenReturn("key");
         when(filterSettings.getUUID()).thenReturn(datasetUId);
         when(perspectiveManager.getCurrentPerspective()).thenReturn(perspectiveActivity);
+        when(serverTemplateSelectorMenuBuilder.getView()).thenReturn(mock(ServerTemplateSelectorMenuBuilder.ServerTemplateSelectorElementView.class));
 
         //Mock that actually calls the callbacks
         doAnswer(new Answer() {
@@ -190,10 +199,11 @@ public abstract class AbstractTaskListPresenterTest {
         }).when(dataSetQueryHelperDomainSpecific).lookupDataSet(anyInt(),
                                                                 any(DataSetReadyCallback.class));
 
-        when(identity.getIdentifier()).thenReturn("userId");
+        when(identity.getIdentifier()).thenReturn(USER_ID);
 
         when(errorHandlerBuilder.get()).thenReturn(errorHandler);
         doNothing().when(errorHandler).showErrorMessage(any());
+        getPresenter().setServerTemplateSelectorMenuBuilder(serverTemplateSelectorMenuBuilder);
     }
 
     protected abstract AbstractTaskListPresenter getPresenter();
@@ -205,11 +215,8 @@ public abstract class AbstractTaskListPresenterTest {
         getPresenter().getData(new Range(0,
                                          5));
 
-        verify(dataSetQueryHelper).lookupDataSet(anyInt(),
-                                                 any(DataSetReadyCallback.class));
-        verify(dataSetQueryHelperDomainSpecific,
-               never()).lookupDataSet(anyInt(),
-                                      any(DataSetReadyCallback.class));
+        verify(dataSetQueryHelper).lookupDataSet(anyInt(), any(DataSetReadyCallback.class));
+        verify(dataSetQueryHelperDomainSpecific, never()).lookupDataSet(anyInt(), any(DataSetReadyCallback.class));
     }
 
     @Test
@@ -218,9 +225,20 @@ public abstract class AbstractTaskListPresenterTest {
 
         getPresenter().releaseTask(task);
 
-        verify(taskService).releaseTask("",
-                                        TASK_DEPLOYMENT_ID,
-                                        TASK_ID);
+        verify(taskService).releaseTask("", TASK_DEPLOYMENT_ID, TASK_ID);
+    }
+
+    @Test
+    public void bulkReleaseTasksTest() {
+        final Map<String, List<Long>> containerTasks = new HashMap<>();
+        List<TaskSummary> taskSummaries = new ArrayList<>();
+        taskSummaries.add(createTestTaskSummary(TASK_ID, TASK_STATUS_RESERVED, identity.getIdentifier()));
+        taskSummaries.add(createTestTaskSummary(TASK_ID + 1, TASK_STATUS_RESERVED, identity.getIdentifier()));
+        taskSummaries.add(createTestTaskSummary(TASK_ID + 2, TASK_STATUS_RESERVED, identity.getIdentifier()));
+
+        getPresenter().bulkRelease(taskSummaries);
+
+        verify(taskService, times(3)).releaseTask(anyString(), eq(TASK_DEPLOYMENT_ID), anyLong());
     }
 
     @Test
@@ -232,6 +250,102 @@ public abstract class AbstractTaskListPresenterTest {
         verify(taskService).claimTask("",
                                       TASK_DEPLOYMENT_ID,
                                       TASK_ID);
+        verify(viewMock).displayNotification(any());
+    }
+
+    @Test
+    public void bulkClaimTasksTest() {
+        List<TaskSummary> taskSummaries = new ArrayList<>();
+        taskSummaries.add(createTestTaskSummary(TASK_ID, TASK_STATUS_READY, ""));
+        taskSummaries.add(createTestTaskSummary(TASK_ID + 1, TASK_STATUS_READY, ""));
+        taskSummaries.add(createTestTaskSummary(TASK_ID + 2, TASK_STATUS_READY, ""));
+
+        getPresenter().bulkClaim(taskSummaries);
+
+        verify(taskService, times(3)).claimTask(anyString(), eq(TASK_DEPLOYMENT_ID), anyLong());
+    }
+
+    @Test
+    public void bulkClaimOnlyOnReadyTasksTest() {
+        List<TaskSummary> taskSummaries = new ArrayList<>();
+        taskSummaries.add(createTestTaskSummary(TASK_ID, TASK_STATUS_RESERVED, identity.getIdentifier()));
+        taskSummaries.add(createTestTaskSummary(TASK_ID + 1, TASK_STATUS_READY, ""));
+        taskSummaries.add(createTestTaskSummary(TASK_ID + 2, TASK_STATUS_READY, ""));
+
+        getPresenter().bulkClaim(taskSummaries);
+
+        verify(taskService, times(2)).claimTask(anyString(), eq(TASK_DEPLOYMENT_ID), anyLong());
+        verify(taskService).claimTask(anyString(), eq(TASK_DEPLOYMENT_ID), eq(TASK_ID + 1));
+        verify(taskService).claimTask(anyString(), eq(TASK_DEPLOYMENT_ID), eq(TASK_ID + 2));
+    }
+
+    @Test
+    public void bulkResumeTasksTest() {
+        final Map<String, List<Long>> containerTasks = new HashMap<>();
+        List<TaskSummary> taskSummaries = new ArrayList<>();
+        taskSummaries.add(createTestTaskSummary(TASK_ID, TASK_STATUS_SUSPENDED, ""));
+        taskSummaries.add(createTestTaskSummary(TASK_ID + 1, TASK_STATUS_SUSPENDED, ""));
+        taskSummaries.add(createTestTaskSummary(TASK_ID + 2, TASK_STATUS_SUSPENDED, ""));
+
+        getPresenter().bulkResume(taskSummaries);
+
+        verify(taskService, times(3)).resumeTask(anyString(), eq(TASK_DEPLOYMENT_ID), anyLong());
+    }
+
+    @Test
+    public void bulkResumeOnlyOnSuspendTasksTest() {
+        List<TaskSummary> taskSummaries = new ArrayList<>();
+        taskSummaries.add(createTestTaskSummary(TASK_ID, TASK_STATUS_RESERVED, identity.getIdentifier()));
+        taskSummaries.add(createTestTaskSummary(TASK_ID + 1, TASK_STATUS_SUSPENDED, ""));
+        taskSummaries.add(createTestTaskSummary(TASK_ID + 2, TASK_STATUS_SUSPENDED, ""));
+
+        getPresenter().bulkResume(taskSummaries);
+
+        verify(taskService, times(2)).resumeTask(anyString(), eq(TASK_DEPLOYMENT_ID), anyLong());
+        verify(taskService).resumeTask(anyString(), eq(TASK_DEPLOYMENT_ID), eq(TASK_ID + 1));
+        verify(taskService).resumeTask(anyString(), eq(TASK_DEPLOYMENT_ID), eq(TASK_ID + 2));
+    }
+
+    @Test
+    public void bulkSuspendTasksTest() {
+        List<TaskSummary> taskSummaries = new ArrayList<>();
+        taskSummaries.add(createTestTaskSummary(TASK_ID, TASK_STATUS_RESERVED, identity.getIdentifier()));
+        taskSummaries.add(createTestTaskSummary(TASK_ID + 1, TASK_STATUS_IN_PROGRESS, ""));
+        taskSummaries.add(createTestTaskSummary(TASK_ID + 2, TASK_STATUS_IN_PROGRESS, ""));
+
+        getPresenter().bulkSuspend(taskSummaries);
+
+        verify(taskService, times(3)).suspendTask(anyString(), eq(TASK_DEPLOYMENT_ID), anyLong());
+        verify(taskService).suspendTask(anyString(), eq(TASK_DEPLOYMENT_ID), eq(TASK_ID));
+        verify(taskService).suspendTask(anyString(), eq(TASK_DEPLOYMENT_ID), eq(TASK_ID + 1));
+        verify(taskService).suspendTask(anyString(), eq(TASK_DEPLOYMENT_ID), eq(TASK_ID + 2));
+    }
+
+    @Test
+    public void bulkSuspendOnlyOnActiveTasksTest() {
+        List<TaskSummary> taskSummaries = new ArrayList<>();
+        taskSummaries.add(createTestTaskSummary(TASK_ID, TASK_STATUS_RESERVED, identity.getIdentifier()));
+        taskSummaries.add(createTestTaskSummary(TASK_ID + 1, TASK_STATUS_IN_PROGRESS, ""));
+        taskSummaries.add(createTestTaskSummary(TASK_ID + 2, TASK_STATUS_SUSPENDED, ""));
+
+        getPresenter().bulkSuspend(taskSummaries);
+
+        verify(taskService, times(2)).suspendTask(anyString(), eq(TASK_DEPLOYMENT_ID), anyLong());
+        verify(taskService).suspendTask(anyString(), eq(TASK_DEPLOYMENT_ID), eq(TASK_ID));
+        verify(taskService).suspendTask(anyString(), eq(TASK_DEPLOYMENT_ID), eq(TASK_ID + 1));
+    }
+
+    @Test
+    public void claimAndWorkTaskTest() {
+        final TaskSummary task = TaskSummary.builder().id(TASK_ID).deploymentId(TASK_DEPLOYMENT_ID).status("Ready").build();
+
+        getPresenter().claimAndWorkTask(task);
+
+        verify(taskService).claimTask("",
+                                      TASK_DEPLOYMENT_ID,
+                                      TASK_ID);
+        verify(placeManager).goTo(PerspectiveIds.TASK_DETAILS_SCREEN);
+        verify(viewMock).displayNotification(any());
     }
 
     @Test
@@ -240,9 +354,7 @@ public abstract class AbstractTaskListPresenterTest {
 
         getPresenter().resumeTask(task);
 
-        verify(taskService).resumeTask("",
-                                       TASK_DEPLOYMENT_ID,
-                                       TASK_ID);
+        verify(taskService).resumeTask("", TASK_DEPLOYMENT_ID, TASK_ID);
     }
 
     @Test
@@ -251,9 +363,7 @@ public abstract class AbstractTaskListPresenterTest {
 
         getPresenter().suspendTask(task);
 
-        verify(taskService).suspendTask("",
-                                        TASK_DEPLOYMENT_ID,
-                                        TASK_ID);
+        verify(taskService).suspendTask("", TASK_DEPLOYMENT_ID, TASK_ID);
     }
 
     @Test
@@ -293,76 +403,56 @@ public abstract class AbstractTaskListPresenterTest {
     @Test
     public void getDomainSpecificDataForTasksTest() {
         final DataSetFilter filter = new DataSetFilter();
-        filter.addFilterColumn(equalsTo(COLUMN_NAME,
-                                        "taskName"));
+        filter.addFilterColumn(equalsTo(COLUMN_NAME, "taskName"));
         filterSettings.getDataSetLookup().addOperation(filter);
 
         when(dataSetMock.getRowCount()).thenReturn(1);//1 task
         //Task summary creation
-        when(dataSetMock.getValueAt(0,
-                                    COLUMN_TASK_ID)).thenReturn(Long.valueOf(1));
+        when(dataSetMock.getValueAt(0, COLUMN_TASK_ID)).thenReturn(Long.valueOf(1));
 
         when(dataSetTaskVarMock.getRowCount()).thenReturn(2); //two domain variables associated
-        when(dataSetTaskVarMock.getValueAt(0,
-                                           COLUMN_TASK_ID
+        when(dataSetTaskVarMock.getValueAt(0, COLUMN_TASK_ID
         )).thenReturn(Long.valueOf(1));
 
         String taskVariable1 = "var1";
-        when(dataSetTaskVarMock.getValueAt(0,
-                                           COLUMN_TASK_VARIABLE_NAME)).thenReturn(taskVariable1);
-        when(dataSetTaskVarMock.getValueAt(0,
-                                           COLUMN_TASK_VARIABLE_VALUE)).thenReturn("value1");
+        when(dataSetTaskVarMock.getValueAt(0, COLUMN_TASK_VARIABLE_NAME)).thenReturn(taskVariable1);
+        when(dataSetTaskVarMock.getValueAt(0, COLUMN_TASK_VARIABLE_VALUE)).thenReturn("value1");
 
-        when(dataSetTaskVarMock.getValueAt(1,
-                                           COLUMN_TASK_ID)).thenReturn(Long.valueOf(1));
+        when(dataSetTaskVarMock.getValueAt(1, COLUMN_TASK_ID)).thenReturn(Long.valueOf(1));
         String taskVariable2 = "var2";
-        when(dataSetTaskVarMock.getValueAt(1,
-                                           COLUMN_TASK_VARIABLE_NAME)).thenReturn(taskVariable2);
-        when(dataSetTaskVarMock.getValueAt(1,
-                                           COLUMN_TASK_VARIABLE_VALUE)).thenReturn("value2");
+        when(dataSetTaskVarMock.getValueAt(1, COLUMN_TASK_VARIABLE_NAME)).thenReturn(taskVariable2);
+        when(dataSetTaskVarMock.getValueAt(1, COLUMN_TASK_VARIABLE_VALUE)).thenReturn("value2");
 
         Set<String> expectedColumns = new HashSet<String>();
         expectedColumns.add(taskVariable1);
         expectedColumns.add(taskVariable2);
 
-        getPresenter().getData(new Range(0,
-                                         5));
+        getPresenter().getData(new Range(0, 5));
 
         ArgumentCaptor<Set> argument = ArgumentCaptor.forClass(Set.class);
         verify(viewMock).addDomainSpecifColumns(argument.capture());
 
         assertEquals(expectedColumns, argument.getValue());
 
-        verify(dataSetQueryHelper).lookupDataSet(anyInt(),
-                                                 any(DataSetReadyCallback.class));
-        verify(dataSetQueryHelperDomainSpecific).lookupDataSet(anyInt(),
-                                                               any(DataSetReadyCallback.class));
+        verify(dataSetQueryHelper).lookupDataSet(anyInt(), any(DataSetReadyCallback.class));
+        verify(dataSetQueryHelperDomainSpecific).lookupDataSet(anyInt(), any(DataSetReadyCallback.class));
 
         when(dataSetTaskVarMock.getRowCount()).thenReturn(1); //one domain variables associated
-        when(dataSetTaskVarMock.getValueAt(0,
-                                           COLUMN_TASK_ID)).thenReturn(Long.valueOf(1));
+        when(dataSetTaskVarMock.getValueAt(0, COLUMN_TASK_ID)).thenReturn(Long.valueOf(1));
         taskVariable1 = "varTest1";
-        when(dataSetTaskVarMock.getValueAt(0,
-                                           COLUMN_TASK_VARIABLE_NAME)).thenReturn(taskVariable1);
-        when(dataSetTaskVarMock.getValueAt(0,
-                                           COLUMN_TASK_VARIABLE_VALUE)).thenReturn("value1");
+        when(dataSetTaskVarMock.getValueAt(0, COLUMN_TASK_VARIABLE_NAME)).thenReturn(taskVariable1);
+        when(dataSetTaskVarMock.getValueAt(0, COLUMN_TASK_VARIABLE_VALUE)).thenReturn("value1");
 
         expectedColumns = Collections.singleton(taskVariable1);
 
-        getPresenter().getData(new Range(0,
-                                         5));
+        getPresenter().getData(new Range(0, 5));
 
         argument = ArgumentCaptor.forClass(Set.class);
         verify(viewMock, times(2)).addDomainSpecifColumns(argument.capture());
 
-        assertEquals(expectedColumns,
-                     argument.getValue());
-        verify(dataSetQueryHelper,
-               times(2)).lookupDataSet(anyInt(),
-                                       any(DataSetReadyCallback.class));
-        verify(dataSetQueryHelperDomainSpecific,
-               times(2)).lookupDataSet(anyInt(),
-                                       any(DataSetReadyCallback.class));
+        assertEquals(expectedColumns, argument.getValue());
+        verify(dataSetQueryHelper, times(2)).lookupDataSet(anyInt(), any(DataSetReadyCallback.class));
+        verify(dataSetQueryHelperDomainSpecific, times(2)).lookupDataSet(anyInt(), any(DataSetReadyCallback.class));
     }
 
     @Test
@@ -376,35 +466,95 @@ public abstract class AbstractTaskListPresenterTest {
         for (final String dataSet : dataSets) {
             when(dataSetMock.getUUID()).thenReturn(dataSet);
 
-            final TaskSummary summary = new TaskSummaryDataSetMapper().apply(dataSetMock,
-                                                                             0);
+            final TaskSummary summary = new TaskSummaryDataSetMapper().apply(dataSetMock, 0);
             assertNotNull(summary);
-            assertEquals(HUMAN_TASKS_WITH_ADMIN_DATASET.equals(dataSet),
-                         summary.isForAdmin());
+            assertEquals(HUMAN_TASKS_WITH_ADMIN_DATASET.equals(dataSet), summary.isForAdmin());
         }
     }
 
     @Test
-    public void testDefaultActiveSearchFilters() {
-        when(translationServiceMock.format(TASK_STATUS_READY.getIdentifier())).thenReturn("Ready");
-        when(translationServiceMock.format(TASK_STATUS_IN_PROGRESS.getIdentifier())).thenReturn("InProgress");
-        when(translationServiceMock.format(TASK_STATUS_RESERVED.getIdentifier())).thenReturn("Reserved");
+    public void testExistActiveSearchFilters() {
+        final PlaceRequest place = mock(PlaceRequest.class);
+        when(place.getParameter(SEARCH_PARAMETER_PROCESS_INSTANCE_ID, null)).thenReturn("1");
+        getPresenter().onStartup(place);
+        assertTrue(getPresenter().existActiveSearchFilters());
 
-        getPresenter().setupDefaultActiveSearchFilters();
+        when(place.getParameter(SEARCH_PARAMETER_TASK_ID, null)).thenReturn("1");
+        assertTrue(getPresenter().existActiveSearchFilters());
+
+        when(place.getParameter(SEARCH_PARAMETER_TASK_ID, null)).thenReturn(null);
+        when(place.getParameter(SEARCH_PARAMETER_PROCESS_INSTANCE_ID, null)).thenReturn(null);
+        assertFalse(getPresenter().existActiveSearchFilters());
+    }
+
+    @Test
+    public void testActiveSearchFiltersProcessInstanceId() {
+        final PlaceRequest place = mock(PlaceRequest.class);
+        final String processInstanceId = "1";
+        when(place.getParameter(SEARCH_PARAMETER_PROCESS_INSTANCE_ID, null)).thenReturn(processInstanceId);
+        getPresenter().onStartup(place);
+
+        getPresenter().setupActiveSearchFilters();
 
         ArgumentCaptor<ActiveFilterItem> captor = ArgumentCaptor.forClass(ActiveFilterItem.class);
         verify(viewMock).addActiveFilter(captor.capture());
 
         final ActiveFilterItem filterItem = captor.getValue();
         assertNotNull(filterItem);
-        assertEquals(Constants.INSTANCE.Status(),
-                     filterItem.getKey());
-        assertEquals(Arrays.asList(TASK_STATUS_READY.getIdentifier(),
-                                   TASK_STATUS_IN_PROGRESS.getIdentifier(),
-                                   TASK_STATUS_RESERVED.getIdentifier()),
-                     filterItem.getValue());
-        assertEquals("Status: Ready, InProgress, Reserved",
-                     filterItem.getLabelValue());
+        assertEquals(Constants.INSTANCE.Process_Instance_Id(), filterItem.getKey());
+        assertEquals(1, filterItem.getValue());
+        assertEquals(Constants.INSTANCE.Process_Instance_Id() + ": " + processInstanceId, filterItem.getLabelValue());
+    }
+
+    @Test
+    public void testSetUpActiveSearchByTaskIdFilters() {
+        final PlaceRequest place = mock(PlaceRequest.class);
+        final String taskId = "1";
+        when(place.getParameter(SEARCH_PARAMETER_TASK_ID, null)).thenReturn(taskId);
+        getPresenter().onStartup(place);
+
+        getPresenter().setupActiveSearchFilters();
+
+        ArgumentCaptor<ActiveFilterItem> captor = ArgumentCaptor.forClass(ActiveFilterItem.class);
+        verify(viewMock).addActiveFilter(captor.capture());
+
+        final ActiveFilterItem filterItem = captor.getValue();
+        assertNotNull(filterItem);
+        assertEquals(Constants.INSTANCE.Task(), filterItem.getKey());
+        assertEquals(1, filterItem.getValue());
+        assertEquals(Constants.INSTANCE.Task() + ": " + taskId, filterItem.getLabelValue());
+    }
+
+    @Test
+    public void testActiveFilterLabelStatus() {
+        String readyTranslation = "Ready_t";
+        String reservedTranslation = "Reserved_t";
+        String inProgressTranslation = "InProgress_t";
+        final List<Comparable> status = new ArrayList<>(getStatusByType(TaskType.ACTIVE));
+        when(translationServiceMock.format("Ready")).thenReturn(readyTranslation);
+        when(translationServiceMock.format("Reserved")).thenReturn(reservedTranslation);
+        when(translationServiceMock.format("InProgress")).thenReturn(inProgressTranslation);
+
+        ColumnFilter testColumFilter = in(COLUMN_STATUS, status);
+        ActiveFilterItem activeFilterItem = getPresenter().getActiveFilterFromColumnFilter(testColumFilter);
+        assertEquals(Constants.INSTANCE.Status(), activeFilterItem.getKey());
+        assertEquals("Status: Ready_t, Reserved_t, InProgress_t", activeFilterItem.getLabelValue());
+        assertEquals(3, ((List) activeFilterItem.getValue()).size());
+        assertNotEquals(testColumFilter.toString(), activeFilterItem.getLabelValue());
+        verify(translationServiceMock, times(3)).format(anyString());
+    }
+
+    @Test
+    public void testActiveFilterLabelOther() {
+        ColumnFilter testColumFilter = equalsTo(COLUMN_PROCESS_INSTANCE_ID, 1);
+        ActiveFilterItem activeFilterItem = getPresenter().getActiveFilterFromColumnFilter(testColumFilter);
+        assertEquals(COLUMN_PROCESS_INSTANCE_ID, activeFilterItem.getKey());
+        assertEquals(testColumFilter.toString(), activeFilterItem.getLabelValue());
+
+        testColumFilter = equalsTo(COLUMN_NAME, "columnName");
+        activeFilterItem = getPresenter().getActiveFilterFromColumnFilter(testColumFilter);
+        assertEquals(COLUMN_NAME, activeFilterItem.getKey());
+        assertEquals(testColumFilter.toString(), activeFilterItem.getLabelValue());
     }
 
     @Test
@@ -435,11 +585,7 @@ public abstract class AbstractTaskListPresenterTest {
 
     @Test
     public void testExitedTaskSelection() {
-        TaskSummary taskSummary = TaskSummary.builder()
-                .id(TASK_ID)
-                .deploymentId(TASK_DEPLOYMENT_ID)
-                .status(TASK_STATUS_EXITED.getIdentifier())
-                .build();
+        TaskSummary taskSummary = createTestTaskSummary(TASK_ID, TASK_STATUS_EXITED, "");
 
         getPresenter().selectSummaryItem(taskSummary);
 
@@ -452,11 +598,9 @@ public abstract class AbstractTaskListPresenterTest {
 
     @Test
     public void testReadyTaskSelection() {
-        TaskSummary taskSummary = TaskSummary.builder()
-                .id(TASK_ID)
-                .deploymentId(TASK_DEPLOYMENT_ID)
-                .status(TASK_STATUS_READY.getIdentifier())
-                .build();
+        Integer slaCompliance = 1;
+        TaskSummary taskSummary = createTestTaskSummary(TASK_ID, TASK_STATUS_READY, "");
+        taskSummary.setSlaCompliance(slaCompliance);
 
         getPresenter().selectSummaryItem(taskSummary);
 
@@ -464,20 +608,15 @@ public abstract class AbstractTaskListPresenterTest {
         final ArgumentCaptor<TaskSelectionEvent> captor = ArgumentCaptor.forClass(TaskSelectionEvent.class);
         verify(taskSelected).fire(captor.capture());
         assertFalse(captor.getValue().isForLog());
+        assertEquals(slaCompliance, captor.getValue().getSlaCompliance());
         assertEquals(taskSummary, getPresenter().getSelectedTask());
     }
 
     @Test
     public void testOnBasicFilterAddEvent() {
-        final ActiveFilterItem<Object> filter = new ActiveFilterItem<>("key1",
-                                                                       null,
-                                                                       null,
-                                                                       null,
-                                                                       null);
+        final ActiveFilterItem<Object> filter = new ActiveFilterItem<>("key1", null, null, null, null);
         final ColumnFilter columnFilter = mock(ColumnFilter.class);
-        getPresenter().onBasicFilterAddEvent(new BasicFilterAddEvent(datasetUId,
-                                                                     filter,
-                                                                     columnFilter));
+        getPresenter().onBasicFilterAddEvent(new BasicFilterAddEvent(datasetUId, filter, columnFilter));
 
         verify(viewMock).addActiveFilter(filter);
         verify(filterSettings).addColumnFilter(columnFilter);
@@ -485,15 +624,9 @@ public abstract class AbstractTaskListPresenterTest {
 
     @Test
     public void testOnBasicFilterRemoveEvent() {
-        final ActiveFilterItem<Object> filter = new ActiveFilterItem<>("key1",
-                                                                       null,
-                                                                       null,
-                                                                       null,
-                                                                       null);
+        final ActiveFilterItem<Object> filter = new ActiveFilterItem<>("key1", null, null, null, null);
         final ColumnFilter columnFilter = mock(ColumnFilter.class);
-        getPresenter().onBasicFilterRemoveEvent(new BasicFilterRemoveEvent(datasetUId,
-                                                                           filter,
-                                                                           columnFilter));
+        getPresenter().onBasicFilterRemoveEvent(new BasicFilterRemoveEvent(datasetUId, filter, columnFilter));
 
         verify(viewMock).removeActiveFilter(filter);
         verify(filterSettings).removeColumnFilter(columnFilter);
@@ -504,15 +637,10 @@ public abstract class AbstractTaskListPresenterTest {
         final String serverTemplateId = "serverTemplateId";
 
         assertFalse(getPresenter().isSameTaskFromEvent().test(new TaskCompletedEvent(serverTemplateId,
-                                                                                    TASK_DEPLOYMENT_ID,
-                                                                                    TASK_ID)));
-
-        TaskSummary taskSummary = TaskSummary.builder()
-                .id(TASK_ID)
-                .deploymentId(TASK_DEPLOYMENT_ID)
-                .status(TASK_STATUS_READY.getIdentifier())
-                .build();
+                                                                                     TASK_DEPLOYMENT_ID,
+                                                                                     TASK_ID)));
 
+        TaskSummary taskSummary = createTestTaskSummary(TASK_ID, TASK_STATUS_READY, "");
 
         getPresenter().setSelectedServerTemplate(new ServerTemplate(serverTemplateId,
                                                                     null,
@@ -524,7 +652,6 @@ public abstract class AbstractTaskListPresenterTest {
         assertTrue(getPresenter().isSameTaskFromEvent().test(new TaskCompletedEvent(serverTemplateId,
                                                                                     TASK_DEPLOYMENT_ID,
                                                                                     TASK_ID)));
-
         assertFalse(getPresenter().isSameTaskFromEvent().test(new TaskCompletedEvent(serverTemplateId,
                                                                                      TASK_DEPLOYMENT_ID,
                                                                                      2l)));
@@ -538,11 +665,7 @@ public abstract class AbstractTaskListPresenterTest {
 
     @Test
     public void testOnTaskCompletedEvent() {
-        TaskSummary taskSummary = TaskSummary.builder()
-                .id(TASK_ID)
-                .deploymentId(TASK_DEPLOYMENT_ID)
-                .status(TASK_STATUS_READY.getIdentifier())
-                .build();
+        TaskSummary taskSummary = createTestTaskSummary(TASK_ID, TASK_STATUS_READY, "");
 
         final String serverTemplateId = "serverTemplateId";
         getPresenter().setSelectedServerTemplate(new ServerTemplate(serverTemplateId,
@@ -561,9 +684,7 @@ public abstract class AbstractTaskListPresenterTest {
                                                                    2l));
 
         //Refreshed 2 times only, one for server template and only one task event
-        verify(extendedPagedTable,
-               times(2)).setVisibleRangeAndClearData(any(),
-                                                     eq(true));
+        verify(extendedPagedTable, times(2)).setVisibleRangeAndClearData(any(), eq(true));
     }
 
     protected static BeforeClosePlaceEvent newCloseEventMock(String placeId) {
@@ -574,24 +695,36 @@ public abstract class AbstractTaskListPresenterTest {
 
     @Test
     public void testOnTaskDetailsClosed() {
-        TaskSummary taskSummary = TaskSummary.builder()
-                .id(TASK_ID)
-                .deploymentId(TASK_DEPLOYMENT_ID)
-                .status(TASK_STATUS_EXITED.getIdentifier())
-                .build();
+        TaskSummary taskSummary = createTestTaskSummary(TASK_ID, TASK_STATUS_EXITED, "");
 
         getPresenter().selectSummaryItem(taskSummary);
 
-        assertEquals(taskSummary,
-                     getPresenter().getSelectedTask());
+        assertEquals(taskSummary, getPresenter().getSelectedTask());
 
         getPresenter().onTaskDetailsClosed(newCloseEventMock(PerspectiveIds.TASK_ADMIN_LIST_SCREEN));
 
-        assertEquals(taskSummary,
-                     getPresenter().getSelectedTask());
+        assertEquals(taskSummary, getPresenter().getSelectedTask());
 
         getPresenter().onTaskDetailsClosed(newCloseEventMock(PerspectiveIds.TASK_DETAILS_SCREEN));
 
         assertNull(getPresenter().getSelectedTask());
     }
+
+    protected TaskSummary createTestTaskSummary(Long taskId, TaskStatus taskStatus, String actualOwner) {
+        Long newTaskId = taskId;
+        String statusStr = TASK_STATUS_READY.getIdentifier();
+        if (taskId == null) {
+            newTaskId = new Random().nextLong();
+        }
+        if (taskStatus != null) {
+            statusStr = taskStatus.getIdentifier();
+        }
+
+        return TaskSummary.builder()
+                .id(newTaskId)
+                .deploymentId(TASK_DEPLOYMENT_ID)
+                .status(statusStr)
+                .actualOwner(actualOwner)
+                .build();
+    }
 }
